
// ----------------- FILE MACROS -----------------


.macro LoadFile(file_number,file_name,file_name_length,load_address)
{
   lda #file_name_length // File name size
   ldx #<file_name
   ldy #>file_name
   jsr SETNAM

   lda #file_number // File number
   ldx #8 // Device
   ldy #0 // Channel
   jsr SETLFS

   lda #0 // Load
   ldx #<load_address
   ldy #>load_address
   jsr LOAD
   bcs error
      jmp doneLoading
   error:
      //sta SCREEN_RAM // Display error code in top left corner of screen
      //lda #1
      //sta SCREEN_COLOR_RAM
      
      // Value of A:
      //$05 Device not present
      //$04 File not found
      //$1D Load error
      //$00 Break run/stop pressed during loading
   doneLoading:
}

.macro SaveFile(file_number,file_name,file_name_length,save_address_start,save_address_end)
{
   lda #file_name_length // File name size
   ldx #<file_name
   ldy #>file_name
   jsr SETNAM

   lda #file_number // File number
   ldx #8 // Device
   ldy #0 // Channel
   jsr SETLFS

   lda #<save_address_start
   sta $c1
   lda #>save_address_start
   sta $c2

   ldx #<save_address_end
   ldy #>save_address_end
   lda #$c1 // Start address located in $C1/$C2
   jsr SAVE
   
   bcs error // If carry set, a load error has happened
      jmp done

   error:
      // Accumulator contains BASIC error code
      sta SCREEN_RAM
   done:
}

.macro CopyData(from_address,to_address,loopIterations) // Loop iterations = X * 256 bytes
{
   lda #<from_address
   sta ZP_DATACOPY_FROM_LO
   lda #>from_address
   sta ZP_DATACOPY_FROM_HI

   lda #<to_address
   sta ZP_DATACOPY_TO_LO
   lda #>to_address
   sta ZP_DATACOPY_TO_HI

   lda PROCESSOR_PORT
   sta processorTemp // Save processor port state

   sei
   lda processorTemp
   and #%11111000 // RAM visible in all three areas
   sta $0001 // Processor Port
   
   dataCopy:
      lda #0
      sta dataCopyCounter

      outerDataCopyLoop:
         ldy #0
         innerDataCopyLoop:
            lda (ZP_DATACOPY_FROM_LO),y
            sta (ZP_DATACOPY_TO_LO),y
            iny
            bne innerDataCopyLoop

         inc ZP_DATACOPY_FROM_HI
         inc ZP_DATACOPY_TO_HI
         inc dataCopyCounter
         lda dataCopyCounter
         cmp #loopIterations
         bne outerDataCopyLoop

   lda processorTemp // Restore processor port state
   sta PROCESSOR_PORT
   cli
}
